<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/ui_mainwindow.h" line="569"/>
        <source>Program_Name</source>
        <translation>Ime_programa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="46"/>
        <location filename="../src/ui_mainwindow.h" line="571"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="49"/>
        <location filename="../src/ui_mainwindow.h" line="573"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <location filename="../src/ui_mainwindow.h" line="575"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="87"/>
        <location filename="../src/ui_mainwindow.h" line="578"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="90"/>
        <location filename="../src/ui_mainwindow.h" line="580"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="96"/>
        <location filename="../src/ui_mainwindow.h" line="582"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="112"/>
        <location filename="../src/ui_mainwindow.h" line="584"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="169"/>
        <location filename="../src/ui_mainwindow.h" line="586"/>
        <source>Next</source>
        <translation>Naslednji</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="194"/>
        <location filename="../src/ui_mainwindow.h" line="591"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="197"/>
        <location filename="../src/ui_mainwindow.h" line="593"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="203"/>
        <location filename="../src/ui_mainwindow.h" line="595"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="219"/>
        <location filename="../src/ui_mainwindow.h" line="597"/>
        <source>View Log</source>
        <translation>Prikaži dnevnik</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="253"/>
        <location filename="../src/mainwindow.cpp" line="583"/>
        <location filename="../src/mainwindow.cpp" line="606"/>
        <location filename="../src/ui_mainwindow.h" line="598"/>
        <source>Select ISO</source>
        <translation>Izberi ISO</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="263"/>
        <location filename="../src/ui_mainwindow.h" line="599"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Izberite ciljni USB nosilec&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="273"/>
        <location filename="../src/ui_mainwindow.h" line="600"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Izberite ISO datoteko&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="289"/>
        <location filename="../src/ui_mainwindow.h" line="601"/>
        <source>Advanced Options</source>
        <translation>Napredne možnosti</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="307"/>
        <location filename="../src/ui_mainwindow.h" line="602"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Napravi datotečni sistem ext4, četudi že obstaja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="314"/>
        <location filename="../src/ui_mainwindow.h" line="603"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Med posodabljanjem živega usb nosilca shrani originalni zagonski direktorij</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="321"/>
        <location filename="../src/ui_mainwindow.h" line="605"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Uporabi gpt razdelke, namesto msdos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <location filename="../src/ui_mainwindow.h" line="607"/>
        <source>GPT partitioning</source>
        <translation>GPT razdeljevanje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="331"/>
        <location filename="../src/ui_mainwindow.h" line="608"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Posodobi (posodobi le obstoječ živi-usb)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="338"/>
        <location filename="../src/ui_mainwindow.h" line="610"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ne nadomesti syslinux datotek</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="341"/>
        <location filename="../src/ui_mainwindow.h" line="612"/>
        <source>Keep syslinux files</source>
        <translation>Obdrži syslinux datoteke</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="348"/>
        <location filename="../src/ui_mainwindow.h" line="613"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignoriraj preverjanje odstranljivosti za USB</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="355"/>
        <location filename="../src/ui_mainwindow.h" line="614"/>
        <source>Temporarily disable automounting</source>
        <translation>Začasno izklopi samodejni priklop</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="365"/>
        <location filename="../src/ui_mainwindow.h" line="618"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Določi zastavico pmbr_boot (ne deluje preko UEFI)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="372"/>
        <location filename="../src/ui_mainwindow.h" line="619"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Ne uporabljajte fuseiso za priklop iso datotek</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="398"/>
        <location filename="../src/ui_mainwindow.h" line="620"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Velikost ESP (uefi) razdelka:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <location filename="../src/ui_mainwindow.h" line="621"/>
        <source>Verbosity (less to more):</source>
        <translation>Podrobnosti (manj do več):</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="465"/>
        <location filename="../src/ui_mainwindow.h" line="623"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="506"/>
        <location filename="../src/ui_mainwindow.h" line="628"/>
        <source>Data partition format type</source>
        <translation>Vrsta formata podatkovnega razdelka</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="460"/>
        <location filename="../src/ui_mainwindow.h" line="622"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="470"/>
        <location filename="../src/ui_mainwindow.h" line="624"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="475"/>
        <location filename="../src/ui_mainwindow.h" line="625"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="499"/>
        <location filename="../src/ui_mainwindow.h" line="627"/>
        <source>Make separate data partition (percent)</source>
        <translation>Ustvari ločen razdelek (odstotki)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="516"/>
        <location filename="../src/ui_mainwindow.h" line="629"/>
        <source>Refresh drive list</source>
        <translation>Osveži seznam pogonov</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="529"/>
        <location filename="../src/mainwindow.cpp" line="552"/>
        <location filename="../src/ui_mainwindow.h" line="630"/>
        <source>Show advanced options</source>
        <translation>Prikaži napredne možnosti</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="548"/>
        <location filename="../src/ui_mainwindow.h" line="631"/>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="563"/>
        <location filename="../src/ui_mainwindow.h" line="632"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Polna funkcionalnost - zapisljiv živi-USB</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="573"/>
        <location filename="../src/ui_mainwindow.h" line="634"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Samo branje. Ne deluje s persistenco</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="576"/>
        <location filename="../src/ui_mainwindow.h" line="636"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>Posnetek diska - samo branje za živi-usb (dd)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="589"/>
        <location filename="../src/ui_mainwindow.h" line="637"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Za distribucije, ki niso antiX/MX, uporabite način posnetek diska (dd).</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="637"/>
        <location filename="../src/ui_mainwindow.h" line="638"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="675"/>
        <location filename="../src/ui_mainwindow.h" line="639"/>
        <source>Percent of USB-device to use:</source>
        <translation>Odstotek rabe USB naprave:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="682"/>
        <location filename="../src/ui_mainwindow.h" line="640"/>
        <source>Label ext partition:</source>
        <translation>Oznaka ext razdelka:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="730"/>
        <location filename="../src/ui_mainwindow.h" line="642"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Ne izvajajte ukazov, ki lahko vplivajo na usb napravo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="733"/>
        <location filename="../src/ui_mainwindow.h" line="644"/>
        <source>Dry run (no change to system)</source>
        <translation>Suh zagon (brez sistemskih sprememb)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="740"/>
        <location filename="../src/ui_mainwindow.h" line="646"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>kloniraj iz priklopljeni živi-usb ali iso datoteko.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="743"/>
        <location filename="../src/ui_mainwindow.h" line="648"/>
        <source>Clone a mounted live system</source>
        <translation>Kloniraj priklopljeni živi sistem</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="750"/>
        <location filename="../src/ui_mainwindow.h" line="650"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Namestitev, ki se zaganja iz šifrirane particije, bo ob prvem zagonu zahtevala vnos varnostne fraze.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="753"/>
        <location filename="../src/ui_mainwindow.h" line="652"/>
        <source>Encrypt</source>
        <translation>Šifriranje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="760"/>
        <location filename="../src/ui_mainwindow.h" line="653"/>
        <source>Clone running live system</source>
        <translation>Kloniraj zagnan živi sistem</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <location filename="../src/mainwindow.cpp" line="537"/>
        <location filename="../src/mainwindow.cpp" line="705"/>
        <source>Failure</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Vir in cilj se nahajata na isti napravi. Prosimo, ponovite izbor.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="750"/>
        <source>Source Error</source>
        <translation>Napaka vira</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="751"/>
        <source>Could not find the source linuxfs file.</source>
        <translation>Ni bilo mogoče najti linuxfs izvorne  datoteke</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="772"/>
        <source>Warning: The target device (%1) is smaller than the source (%2). The data might not fit. Do you want to continue?</source>
        <translation>Opozorilo: Ciljna naprava (%1) je manjša od vira (%2), zato je lahko podatkov preveč. Ali želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="775"/>
        <source>Size Warning</source>
        <translation>Opozorilo o velikosti</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="783"/>
        <source>The target device %1 is larger than %2 GB.

This may indicate you have selected the wrong device.
Are you sure you want to proceed?</source>
        <translation>Ciljna naprava %1 je večja od %2 GB.

To je lahko posledica izbora napačnega pogona.
Ali res želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="790"/>
        <source>Large Target Device Warning</source>
        <translation>Opozorilo o velikem pogonu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the process is completed</source>
        <translation>Zapisovanje %1 z uporabo ukaza &apos;dd&apos; na /dev/%2,

Počakajte, da se postopek zaključi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="205"/>
        <source>MX Live Usb Maker</source>
        <translation>MX Ustvarjalnik živih usb ključkov</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <source>Success</source>
        <translation>Operacija je uspela</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <source>LiveUSB creation successful!</source>
        <translation>ŽiviUSB je bil uspešno ustvarjen!</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>ŽiviUSB ni bil uspešno ustvarjen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="464"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="464"/>
        <source>Please select a USB device to write to</source>
        <translation>Izberite USB napravo, na katero naj se zapisuje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="467"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Ta dejanje bodo uničila vse podatke na 

</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="468"/>
        <source>Do you wish to continue?</source>
        <translation>Ali želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="500"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="501"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="503"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program, ki ustvari živi-usb iz iso datoteke, drugega živega usb pogona, živega cd/dvd ploščka ali iz sistema, ki je zagnan v živo.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="506"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="507"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="514"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="522"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Izberite ISO datoteko, ki naj se zapiše na USB pogon</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="523"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>ISO datoteke (*.iso);;Vse datoteke (*.*)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="528"/>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Select Source Directory</source>
        <translation>Izberite direktorij z virom</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="537"/>
        <source>Could not find linuxfs file</source>
        <translation>Ni bilo mogoče najti linuxfs datoteke</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="552"/>
        <source>Hide advanced options</source>
        <translation>Skrij napredne možnosti</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <location filename="../src/mainwindow.cpp" line="596"/>
        <source>Select Source</source>
        <translation>Izberi vir</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="582"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Select ISO file</source>
        <translation>Izberi ISO datoteko</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="598"/>
        <source>clone</source>
        <translation>kloniraj</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="665"/>
        <source>Could not find a log file at: </source>
        <translation>Nisem našel dnevnika v:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="74"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <location filename="../src/about.cpp" line="85"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="76"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="99"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program, ki ustvari živi-usb iz iso datoteke, drugega živega usb pogona, živega cd/dvd ploščka ali iz sistema, ki je zagnan v živo.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>filename</source>
        <translation>ime datoteke</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Name of .iso file to open</source>
        <translation>Ime .iso datoteke za odpiranje</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="65"/>
        <source>[filename]</source>
        <translation>[ime datoteke]</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <location filename="../src/main.cpp" line="102"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="94"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Prijevljeni ste kot korenski uporabnik. Izpišite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="102"/>
        <source>You must run this program as root.</source>
        <translation>Ta program morate zagnati korensko</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>version:</source>
        <translation>različica:</translation>
    </message>
</context>
</TS>